@@ -3,6 +3,7 @@ from sqlalchemy import (
     Integer,
     String,
     DateTime,
+    ForeignKey,
 )
 from datetime import datetime
 
@@ -18,6 +19,11 @@ class CompanyTickerOutboxModel(Base):
     ticker = Column(String(20), nullable=False, index=True)
     name = Column(String(255), nullable=False, index=True)
     exchange = Column(String(50), nullable=True)
+    news_id = Column(
+        Integer,
+        ForeignKey('newswires.id'),
+        nullable=True,
+    )
     updated_at = Column(
         DateTime,
         default=datetime.utcnow,
