@@ -32,6 +32,16 @@ class DocTextModel(Base):
         ForeignKey('company_filings.id'),
         nullable=True,
     )
+    company_scientific_link_id = Column(
+        Integer,
+        ForeignKey('company_scientific_links.id'),
+        nullable=True,
+    )
+    pubmed_id = Column(
+        Integer,
+        ForeignKey('pubmed.id'),
+        nullable=True,
+    )
     text_type = Column(String(20), nullable=True)
     text = Column(Text, nullable=False)
     preferred = Column(Boolean, nullable=True)
