@@ -8,6 +8,7 @@ from sqlalchemy import (
     Text,
     String,
     DECIMAL,
+    Boolean,
 )
 
 from ...database import Base
@@ -39,6 +40,7 @@ class IPOOutboxModel(Base):
     )
     underwriters = Column(Text, nullable=True)
     counsels = Column(Text, nullable=True)
+    reviewed = Column(Boolean, nullable=True)
     updated_at = Column(
         DateTime,
         nullable=False,
