@@ -6,6 +6,7 @@ from sqlalchemy import (
     DateTime,
     ForeignKey,
     Text,
+    Boolean
 )
 
 from ...database import Base
@@ -24,6 +25,7 @@ class LicensingCollabOutboxModel(Base):
     upfronts = Column(Text, nullable=True)
     milestones = Column(Text, nullable=True)
     sentences = Column(Text, nullable=True)
+    reviewed = Column(Boolean, nullable=True)
     updated_at = Column(
         DateTime,
         nullable=False,
