@@ -30,7 +30,7 @@ class PacerCaseResourceSchema(Schema):
     updated_at = fields.DateTime(dump_only=True)
 
     @pre_load
-    def convert_string_to_datetime(self, in_data):
+    def convert_string_to_datetime(self, in_data, **kwargs):
         date_fields = ['filed_date', 'terminated_date']
 
         in_data = pre_load_date_fields(
@@ -51,7 +51,7 @@ class PacerCaseQueryParamsSchema(Schema):
     pacer_case_external_id = fields.String()
 
     @pre_load
-    def convert_string_to_datetime(self, in_data):
+    def convert_string_to_datetime(self, in_data, **kwargs):
         date_fields = ['filed_date', 'terminated_date']
 
         in_data = pre_load_date_fields(
@@ -83,7 +83,7 @@ class PacerCasePatchSchema(Schema):
     terminated_date = fields.DateTime()
 
     @pre_load
-    def convert_string_to_datetime(self, in_data):
+    def convert_string_to_datetime(self, in_data, **kwargs):
         date_fields = ['filed_date', 'terminated_date']
 
         in_data = pre_load_date_fields(
